@@ -49,7 +49,7 @@ module FFaker
       if allow_first_zero
         FFaker.numerify(masks_arr)
       else
-        fetch_sample(masks_arr).sub(/#/) { rand(1..9).to_s }.gsub(/#/) { rand(0..9).to_s }
+        fetch_sample(masks_arr).sub('#') { rand(1..9).to_s }.gsub('#') { rand(0..9).to_s }
       end
     end
   end
