@@ -11,7 +11,7 @@ module FFaker
     GENDERS = %i[random female male].freeze
     MALE_PREFIXES = %w[Pan].freeze
     FEMALE_PREFIXES = %w[Pani].freeze
-    ACADEMIC_DEGREE_PREFIXES = %w[lic. inż. mgr mgr\ inż. dr dr\ hab. prof.].freeze
+    ACADEMIC_DEGREE_PREFIXES = ['lic.', 'inż.', 'mgr', 'mgr inż.', 'dr', 'dr hab.', 'prof.'].freeze
     PREFIXES = (MALE_PREFIXES + FEMALE_PREFIXES + ACADEMIC_DEGREE_PREFIXES).freeze
 
     # Generates a random full name for a given gender (random by default).
