@@ -20,11 +20,11 @@ class TestAddressDA < Test::Unit::TestCase
   end
 
   def test_state
-    assert_match(/\A[-ÆØÅæøåa-z-]+\z/i, FFaker::AddressDA.state)
+    assert_match(/\A[-ÆØÅæøåa-z]+\z/i, FFaker::AddressDA.state)
   end
 
   def test_kommune
-    assert_match(/\A[-ÆØÅæøåa-z-]+\z/i, FFaker::AddressDA.kommune)
+    assert_match(/\A[-ÆØÅæøåa-z]+\z/i, FFaker::AddressDA.kommune)
   end
 
   def test_region
@@ -32,7 +32,7 @@ class TestAddressDA < Test::Unit::TestCase
   end
 
   def test_city
-    assert_match(/\A[- ÆØÅæøåla-z-]+\z/i, FFaker::AddressDA.city)
+    assert_match(/\A[- ÆØÅæøåla-z]+\z/i, FFaker::AddressDA.city)
   end
 
   def test_street_name
