@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestAddressID < Test::Unit::TestCase
   include DeterministicHelper
@@ -33,7 +33,7 @@ class TestAddressID < Test::Unit::TestCase
   def test_street
     prefixes = FFaker::AddressID::STREET_PREFIX
     common_street_names = FFaker::AddressID::COMMON_STREET_NAMES
-    regex = /\A(#{prefixes.join('|')})\.(\s(#{common_street_names.join('|')}))\,\sNo\.\s\d+\z/
+    regex = /\A(#{prefixes.join('|')})\.(\s(#{common_street_names.join('|')})),\sNo\.\s\d+\z/
     assert_match(regex, FFaker::AddressID.street)
   end
 end
