@@ -5,7 +5,7 @@ require_relative 'helper'
 class TestFakerGenderJP < Test::Unit::TestCase
   include DeterministicHelper
 
-  GENDER_REGEX = /\A[女男]\z/.freeze
+  GENDER_REGEX = /\A[女男]\z/
 
   assert_methods_are_deterministic(FFaker::GenderJP, :random)
 
