@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestFakerIdentificationESCL < Test::Unit::TestCase
   include DeterministicHelper
@@ -12,6 +12,6 @@ class TestFakerIdentificationESCL < Test::Unit::TestCase
   end
 
   def test_rut
-    assert_match(/\b\d{7,8}\-[k|0-9]/i, @tester.rut)
+    assert_match(/\b\d{7,8}-[k|0-9]/i, @tester.rut)
   end
 end
