@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestMusic < Test::Unit::TestCase
   include DeterministicHelper
@@ -11,18 +11,18 @@ class TestMusic < Test::Unit::TestCase
   )
 
   def test_genre
-    assert_match(%r{[A-z]|\W|\&/+}, FFaker::Music.genre)
+    assert_match(%r{[A-z]|\W|&/+}, FFaker::Music.genre)
   end
 
   def test_album
-    assert_match(/\s|[A-z]|\W|\d|\'|\?+/, FFaker::Music.album)
+    assert_match(/\s|[A-z]|\W|\d|'|\?+/, FFaker::Music.album)
   end
 
   def test_artist
-    assert_match(/\s|[A-z]|\W|\d|\'|\?|\&|\+|\.|\-+/, FFaker::Music.artist)
+    assert_match(/\s|[A-z]|\W|\d|'|\?|&|\+|\.|-+/, FFaker::Music.artist)
   end
 
   def test_song
-    assert_match(/\s|[A-z]|\W|\d|\'|\?|\&|\+|\.|\-+/, FFaker::Music.song)
+    assert_match(/\s|[A-z]|\W|\d|'|\?|&|\+|\.|-+/, FFaker::Music.song)
   end
 end
